==> nextcloud-23.0.5.tgz: nextcloud/apps/weather_status/l10n/fr.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adresse inconnue",
    "No result." : "Aucun résultat",
    "Malformed JSON data." : "Données JSON mal formées.",
    "Error" : "Erreur",
    "Weather status" : "Statut météo",
    "Weather status in your dashboard" : "Statut météo sur votre tableau de bord",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Statut météo intégré dans l'application Dashboard.\nLa position de l'utilisateur peut être déterminée automatiquement ou définie manuellement. Une prévision de 6 heures est alors affichée.\nCe statut peut également être intégré à d'autres endroits comme l'application Calendrier.",
    "Detect location" : "Détecter la position",
    "Set custom address" : "Définir une adresse personnalisée",
    "Favorites" : "Favoris",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Ciel dégagé dans la journée",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Ciel dégagé",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} Nuageux dans la journée",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Nuageux",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} Beau temps dans la journée",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Beau temps",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} Partiellement nuageux dans la journée",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Partiellement nuageux",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} Brouillard dans la journée",
    "{temperature} {unit} foggy" : "{temperature} {unit} Brouillard",
    "More weather for {adr}" : "Plus de météo pour {adr}",
    "Loading weather" : "Chargement de la météo",
    "Remove from favorites" : "Retirer des favoris",
    "Add as favorite" : "Ajouter comme favori",
    "You are not logged in." : "Vous n'êtes pas connecté.",
    "There was an error getting the weather status information." : "Une erreur s'est produite lors de l'obtention des informations sur l'état de la météo.",
    "No weather information found" : "Aucune information météo",
    "Location not found" : "Lieu non trouvé",
    "There was an error setting the location address." : "Une erreur s'est produite lors de la définition de l'adresse de l'emplacement.",
    "There was an error setting the location." : "Une erreur s'est produite lors de la définition de l'emplacement.",
    "There was an error saving the mode." : "Une erreur s'est produite lors de l'enregistrement du mode.",
    "There was an error using personal address." : "Une erreur s'est produite lors de l'utilisation de l'adresse personnelle.",
    "Set location for weather" : "Définir l'emplacement pour la météo",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Ciel dégagé à {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nuageux à {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Beau jour à {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Bonne nuit à {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Partiellement nuageux à {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Brouillard à {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Faible pluie à {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Pluie à {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Fortes pluies à {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Averses à {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Faibles averses à {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Fortes averses à {time}"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-24.0.5.tgz: nextcloud/apps/weather_status/l10n/fr.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adresse inconnue",
    "No result." : "Aucun résultat",
    "Malformed JSON data." : "Données JSON mal formées.",
    "Error" : "Erreur",
    "Weather status" : "Statut météo",
    "Weather status in your dashboard" : "Statut météo sur votre tableau de bord",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Statut météo intégré dans l'application Dashboard.\nLa position de l'utilisateur peut être déterminée automatiquement ou définie manuellement. Une prévision de 6 heures est alors affichée.\nCe statut peut également être intégré à d'autres endroits comme l'application Calendrier.",
    "Detect location" : "Détecter la position",
    "Set custom address" : "Définir une adresse personnalisée",
    "Favorites" : "Favoris",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Ciel dégagé dans la journée",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Ciel dégagé",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} Nuageux dans la journée",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Nuageux",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} Beau temps dans la journée",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Beau temps",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} Partiellement nuageux dans la journée",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Partiellement nuageux",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} Brouillard dans la journée",
    "{temperature} {unit} foggy" : "{temperature} {unit} Brouillard",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} Pluie légère dans la journée",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} Pluie légère",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} Pluie dans la journée",
    "{temperature} {unit} rainfall" : "{temperature} {unit} Pluie",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} Fortes pluies dans la journée",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} Fortes pluies",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} Averses dans la journée",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} Averses",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} Faibles averses dans la journée",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} Faibles averses",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} Fortes averses dans la journée",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} Fortes averses",
    "More weather for {adr}" : "Plus de météo pour {adr}",
    "Loading weather" : "Chargement de la météo",
    "Remove from favorites" : "Retirer des favoris",
    "Add as favorite" : "Ajouter comme favori",
    "You are not logged in." : "Vous n'êtes pas connecté.",
    "There was an error getting the weather status information." : "Une erreur s'est produite lors de l'obtention des informations sur l'état de la météo.",
    "No weather information found" : "Aucune information météo",
    "Location not found" : "Lieu non trouvé",
    "There was an error setting the location address." : "Une erreur s'est produite lors de la définition de l'adresse de l'emplacement.",
    "There was an error setting the location." : "Une erreur s'est produite lors de la définition de l'emplacement.",
    "There was an error saving the mode." : "Une erreur s'est produite lors de l'enregistrement du mode.",
    "There was an error using personal address." : "Une erreur s'est produite lors de l'utilisation de l'adresse personnelle.",
    "Set location for weather" : "Définir l'emplacement pour la météo",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Ciel dégagé à {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nuageux à {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Beau jour à {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Bonne nuit à {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Partiellement nuageux à {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Brouillard à {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Faible pluie à {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Pluie à {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Fortes pluies à {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Averses à {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Faibles averses à {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Fortes averses à {time}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
